@@ -7,8 +7,11 @@ from functools import wraps
 import inspect
 import logging
 from logging import LoggerAdapter
+import os
 from timeit import default_timer
 
+from .logging_handlers import MAGIC_PREFIX
+
 
 class AnnotatedLogger:
     """Contextmanager to temporary annotate the current global logger with extra kwargs.
@@ -114,6 +117,7 @@ def autolog(logger_name='logger', level=logging.DEBUG, log_before=True, log_afte
                 result: the result of the decorated function call
             """
             func_fullname = ".".join([function.__module__, function.__qualname__])
+            func_file = inspect.getsourcefile(function)
             func_sig = inspect.signature(function)
             bound_args = func_sig.bind(*args, **kwargs)
             bound_args.apply_defaults()
@@ -122,6 +126,18 @@ def autolog(logger_name='logger', level=logging.DEBUG, log_before=True, log_afte
             for key, value in func_kwargs.items():
                 logger_extra['arg_{}'.format(key)] = value
 
+            # override some of the logrecord attributes, prepend magic prefix to avoid name clashes
+            overrides = dict(
+                funcName=func_fullname,
+                filename=os.path.basename(func_file),
+                module=inspect.getmodule(function).__name__,
+                name=function.__name__,
+                pathname=func_file,
+                lineno=inspect.getsourcelines(function)[-1]
+            )
+            overrides = {'{}{}'.format(MAGIC_PREFIX, k):v for k,v in overrides.items()}
+            logger_extra.update(overrides)
+
             with AnnotatedLogger(logger_name, **logger_extra) as logger:
 
                 if log_before:
